@@ -1,6 +1,3 @@
-.onAttach <- function(lib, pkg)
-{
-
+.onAttach <- function(lib, pkg) {
   packageStartupMessage(paste0("pxweb ", utils::packageVersion("pxweb"), ": R tools for the PX-WEB API.\nhttps://github.com/ropengov/pxweb\n"))
-
 }
